@@ -319,6 +319,35 @@ eval_dirty <- function(expr, env = parent.frame(), data = NULL, quoted = TRUE){
 }
 
 
+#' Get an element with condition that it must be from a list or vector
+#' @param lhs the element of candidate
+#' @param rhs the constraint
+#' @return Returns an element of length one that will be from \code{rhs}
+#' @examples
+#'
+#' # C is from LETTERS, therefore returns `C`
+#' "C" %OF% LETTERS
+#'
+#'
+#' # `lhs` is not from `rhs`, hence return the first element of LETTERS
+#' '9' %OF% LETTERS
+#' NULL %OF% LETTERS
+#'
+#' # When there are multiple elements from `lhs`, select the first that
+#' # matches the constraint
+#' c('9', "D", "V") %OF% LETTERS
+#'
+#' @export
+`%OF%` <- function(lhs, rhs){
+  if(length(rhs)){ de <- rhs[[1]] } else { de <- rhs }
+  lhs <- lhs[!is.na(lhs)]
+  if(!length(lhs)){ return(de) }
+  sel <- lhs %in% rhs
+  if(any(sel)){ return(lhs[sel][[1]]) }
+  return(de)
+}
+
+
 #' A JavaScript style of creating functions
 #' @param args function arguments: see \code{\link[base]{formals}}
 #' @param expr R expression that forms the body of functions: see \code{\link[base]{body}}
